@@ -9,7 +9,7 @@ use strict;
 use Lemonldap::NG::Portal::Simple;
 use URI::Escape;
 
-our $VERSION = '1.2.2_01';
+our $VERSION = '1.2.3';
 our $initDone;
 
 BEGIN {
@@ -71,7 +71,7 @@ sub extractFormInfo {
 
         foreach ( keys %{ $self->{portalHiddenFormValues} } ) {
             $local_url .=
-                ( $local_url =~ /\?/ ? '&' : '?' ) 
+                ( $local_url =~ /\?/ ? '&' : '?' )
               . $_ . '='
               . uri_escape( $self->{portalHiddenFormValues}->{$_} );
         }
@@ -259,7 +259,7 @@ __END__
 =encoding utf8
 
 Lemonldap::NG::Portal::AuthCAS - Perl extension for building Lemonldap::NG
-compatible portals with CAS authentication. EXPERIMENTAL AND NOT FINISHED!
+compatible portals with CAS authentication.
 
 =head1 SYNOPSIS
 
@@ -274,7 +274,7 @@ compatible portals with CAS authentication. EXPERIMENTAL AND NOT FINISHED!
   if($portal->process()) {
     # Write here the menu with CGI methods. This page is displayed ONLY IF
     # the user was not redirected here.
-    print $portal->header('text/html; charset=utf8'); # DON'T FORGET THIS (see CGI(3))
+    print $portal->header('text/html; charset=utf-8'); # DON'T FORGET THIS (see CGI(3))
     print "...";
 
     # or redirect the user to the menu
@@ -282,7 +282,7 @@ compatible portals with CAS authentication. EXPERIMENTAL AND NOT FINISHED!
   }
   else {
     # If the user enters here, IT MEANS THAT CAS REDIRECTION DOES NOT WORK
-    print $portal->header('text/html; charset=utf8'); # DON'T FORGET THIS (see CGI(3))
+    print $portal->header('text/html; charset=utf-8'); # DON'T FORGET THIS (see CGI(3))
     print "<html><body><h1>Unable to work</h1>";
     print "This server isn't well configured. Contact your administrator.";
     print "</body></html>";
@@ -302,7 +302,15 @@ L<http://lemonldap-ng.org/>
 
 =head1 AUTHOR
 
-Xavier Guimard, E<lt>x.guimard@free.frE<gt>
+=over
+
+=item Clement Oudot, E<lt>clem.oudot@gmail.comE<gt>
+
+=item Xavier Guimard, E<lt>x.guimard@free.frE<gt>
+
+=item Thomas Chemineau, E<lt>thomas.chemineau@gmail.comE<gt>
+
+=back
 
 =head1 BUG REPORT
 
@@ -316,11 +324,28 @@ L<http://forge.objectweb.org/project/showfiles.php?group_id=274>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2007, 2010 by Xavier Guimard E<lt>x.guimard@free.frE<gt>
+=over
+
+=item Copyright (C) 2007-2010 by Xavier Guimard, E<lt>x.guimard@free.frE<gt>
+
+=item Copyright (C) 2009-2016 by Clement Oudot, E<lt>clem.oudot@gmail.comE<gt>
+
+=item Copyright (C) 2009 by Thomas Chemineau, E<lt>thomas.chemineau@gmail.comE<gt>
+
+=back
 
 This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself, either Perl version 5.10.0 or,
-at your option, any later version of Perl 5 you may have available.
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation; either version 2, or (at your option)
+any later version.
+
+This program is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with this program.  If not, see L<http://www.gnu.org/licenses/>.
 
 =cut
 
