@@ -11,7 +11,7 @@ use Lemonldap::NG::Portal::Simple;
 use Lemonldap::NG::Portal::_SAML;    #inherits
 use Lemonldap::NG::Common::Conf::SAML::Metadata;
 
-our $VERSION = '1.4.11';
+our $VERSION = '1.9.0';
 our @ISA     = qw(Lemonldap::NG::Portal::_SAML);
 
 ## @apmethod int authInit()
@@ -801,7 +801,8 @@ sub extractFormInfo {
                 name => $self->{_idpList}->{$_}->{name}
               };
         }
-        $self->{list} = \@list;
+        $self->{list}            = \@list;
+        $self->{confirmRemember} = 1;
 
         # Delete existing IDP resolution cookie
         push @{ $self->{cookie} },
@@ -1130,18 +1131,7 @@ sub setAuthSessionInfo {
     # Dump Lasso objects in session
     $self->{sessionInfo}->{_lassoSessionDump}  = $session->dump()  if $session;
     $self->{sessionInfo}->{_lassoIdentityDump} = $identity->dump() if $identity;
-
-    # Keep SAML Token in session
-    my $store_samlToken =
-      $self->{samlIDPMetaDataOptions}->{$idpConfKey}
-      ->{samlIDPMetaDataOptionsStoreSAMLToken};
-    if ($store_samlToken) {
-        $self->lmLog( "Store SAML Token in session", 'debug' );
-        $self->{sessionInfo}->{_samlToken} = $self->{_samlToken};
-    }
-    else {
-        $self->lmLog( "SAML Token will not be stored in session", 'debug' );
-    }
+    $self->{sessionInfo}->{_samlToken} = $self->{_samlToken};
 
     $self->{_lassoLogin} = $login;
 
@@ -1295,11 +1285,11 @@ sub authLogout {
         $method = $self->getFirstHttpMethod( $server, $idp, $protocolType );
     }
 
-    # Skip SLO if no method found
+    # Failback to SOAP
     unless ( defined $method and $method != -1 ) {
         $self->lmLog( "No method found with IDP $idpConfKey for SLO profile",
             'debug' );
-        return PE_OK;
+        $method = $self->getHttpMethod("soap");
     }
 
     $self->lmLog(
@@ -1445,16 +1435,9 @@ sub authForce {
 }
 
 ## @apmethod boolean authFinish()
-# Do nothing
-# @return Lemonldap::NG::Portal error code
-sub authFinish {
-    PE_OK;
-}
-
-## @apmethod boolean authPostStore()
 # Associate NameID and SessionIndex to a local session
 # @return Lemonldap::NG::Portal error code
-sub authPostStore {
+sub authFinish {
     my $self = shift;
     my %h;
 
@@ -1552,13 +1535,13 @@ L<http://forge.objectweb.org/project/showfiles.php?group_id=274>
 
 =over
 
-=item Copyright (C) 2009, 2010 by Xavier Guimard, E<lt>x.guimard@free.frE<gt>
+=item Copyright (C) 2009-2010 by Xavier Guimard, E<lt>x.guimard@free.frE<gt>
 
 =item Copyright (C) 2012 by Sandro Cazzaniga, E<lt>cazzaniga.sandro@gmail.comE<gt>
 
 =item Copyright (C) 2012 by François-Xavier Deltombe, E<lt>fxdeltombe@gmail.com.E<gt>
 
-=item Copyright (C) 2010, 2011, 2012 by Clement Oudot, E<lt>clem.oudot@gmail.comE<gt>
+=item Copyright (C) 2010-2015 by Clement Oudot, E<lt>clem.oudot@gmail.comE<gt>
 
 =item Copyright (C) 2010 by Thomas Chemineau, E<lt>thomas.chemineau@gmail.comE<gt>
 
