@@ -9,9 +9,8 @@ use strict;
 use Lemonldap::NG::Portal::Simple;
 use Lemonldap::NG::Portal::_CAS;
 use base qw(Lemonldap::NG::Portal::_CAS Lemonldap::NG::Portal::_LibAccess);
-use URI;
 
-our $VERSION = '1.4.9';
+our $VERSION = '1.9.0';
 
 ## @method void issuerDBInit()
 # Nothing to do
@@ -137,37 +136,19 @@ sub issuerForUnAuthUser {
 
         $self->lmLog( "Service ticket session $ticket found", 'debug' );
 
-        my $service1_uri = URI->new($service);
-        my $service2_uri = URI->new( $casServiceSession->data->{service} );
-
         # Check service
-        unless ( $service1_uri->eq($service2_uri) ) {
+        unless ( $service eq $casServiceSession->data->{service} ) {
+            $self->lmLog(
+                "Submitted service $service does not match initial service "
+                  . $casServiceSession->data->{service},
+                'error'
+            );
+            $self->deleteCasSession($casServiceSession);
+            $self->returnCasValidateError();
+        }
 
-            # Tolerate that relative URI are the same
-            if (   $service1_uri->rel($service2_uri) eq "./"
-                or $service2_uri->rel($service1_uri) eq "./" )
-            {
-                $self->lmLog(
-"Submitted service $service1_uri does not exactly match initial service "
-                      . $service2_uri
-                      . ' but difference is tolerated.',
-                    'warn'
-                );
-            }
-            else {
-                $self->lmLog(
-                    "Submitted service $service does not match initial service "
-                      . $casServiceSession->data->{service},
-                    'error'
-                );
-                $self->deleteCasSession($casServiceSession);
-                $self->returnCasValidateError();
-            }
-        }
-        else {
-            $self->lmLog( "Submitted service $service math initial servce",
-                'debug' );
-        }
+        $self->lmLog( "Submitted service $service math initial servce",
+            'debug' );
 
         # Check renew
         if ( $renew eq 'true' ) {
@@ -278,39 +259,21 @@ sub issuerForUnAuthUser {
 
         $self->lmLog( "$urlType ticket session $ticket found", 'debug' );
 
-        my $service1_uri = URI->new($service);
-        my $service2_uri = URI->new( $casServiceSession->data->{service} );
-
         # Check service
-        unless ( $service1_uri->eq($service2_uri) ) {
+        unless ( $service eq $casServiceSession->data->{service} ) {
+            $self->lmLog(
+                "Submitted service $service does not match initial service "
+                  . $casServiceSession->data->{service},
+                'error'
+            );
 
-            # Tolerate that relative URI are the same
-            if (   $service1_uri->rel($service2_uri) eq "./"
-                or $service2_uri->rel($service1_uri) eq "./" )
-            {
-                $self->lmLog(
-"Submitted service $service1_uri does not exactly match initial service "
-                      . $service2_uri
-                      . ' but difference is tolerated.',
-                    'warn'
-                );
-            }
-            else {
-                $self->lmLog(
-                    "Submitted service $service does not match initial service "
-                      . $casServiceSession->data->{service},
-                    'error'
-                );
+            $self->deleteCasSession($casServiceSession);
+            $self->returnCasServiceValidateError( 'INVALID_SERVICE',
+                'Submitted service does not match initial service' );
+        }
 
-                $self->deleteCasSession($casServiceSession);
-                $self->returnCasServiceValidateError( 'INVALID_SERVICE',
-                    'Submitted service does not match initial service' );
-            }
-        }
-        else {
-            $self->lmLog( "Submitted service $service match initial service",
-                'debug' );
-        }
+        $self->lmLog( "Submitted service $service match initial servce",
+            'debug' );
 
         # Check renew
         if ( $renew eq 'true' ) {
@@ -433,10 +396,22 @@ sub issuerForUnAuthUser {
 
         $self->lmLog( "Get username $username", 'debug' );
 
+        # Get attributes [CAS 3.0]
+        my $attributes = {};
+        if ( defined $self->{casAttributes} ) {
+            foreach my $casAttribute ( keys %{ $self->{casAttributes} } ) {
+                my $localSessionValue =
+                  $localSession->data->{ $self->{casAttributes}->{$casAttribute}
+                  };
+                $attributes->{$casAttribute} = $localSessionValue
+                  if defined $localSessionValue;
+            }
+        }
+
         # Return success message
         $self->deleteCasSession($casServiceSession);
         $self->returnCasServiceValidateSuccess( $username,
-            $casProxyGrantingTicketIOU, $proxies );
+            $casProxyGrantingTicketIOU, $proxies, $attributes );
 
         # We should not be there
         return PE_ERROR;
@@ -829,7 +804,7 @@ L<http://forge.objectweb.org/project/showfiles.php?group_id=274>
 
 =item Copyright (C) 2012 by François-Xavier Deltombe, E<lt>fxdeltombe@gmail.com.E<gt>
 
-=item Copyright (C) 2010, 2011, 2012 by Clement Oudot, E<lt>clem.oudot@gmail.comE<gt>
+=item Copyright (C) 2010-2012 by Clement Oudot, E<lt>clem.oudot@gmail.comE<gt>
 
 =back
 
