@@ -11,7 +11,7 @@ use Lemonldap::NG::Portal::Simple;
 use Lemonldap::NG::Portal::_SAML;
 our @ISA = qw(Lemonldap::NG::Portal::_SAML);
 
-our $VERSION = '1.4.2';
+our $VERSION = '1.9.0';
 
 ## @method void issuerDBInit()
 # Load and check SAML configuration
@@ -213,13 +213,6 @@ sub issuerForUnAuthUser {
             $self->{_proxiedRelayState}  = $relaystate;
             $self->{_proxiedArtifact}    = $artifact;
 
-            # Create a back link on SP displayed on login page
-            my $html =
-                "<a href=\""
-              . $self->referer() . "\">"
-              . $self->msg(PM_BACKTOSP) . "</a>";
-            $self->loginInfo($html);
-
             return PE_OK;
         }
 
@@ -1583,8 +1576,8 @@ sub issuerForAuthUser {
             my @attributes;
 
             foreach (
-                keys
-                %{ $self->{samlSPMetaDataExportedAttributes}->{$spConfKey} } )
+                keys %{ $self->{samlSPMetaDataExportedAttributes}->{$spConfKey}
+                } )
             {
 
                 # Extract fields from exportedAttr value
@@ -2283,11 +2276,11 @@ L<http://forge.objectweb.org/project/showfiles.php?group_id=274>
 
 =over
 
-=item Copyright (C) 2009, 2010, 2012 by Xavier Guimard, E<lt>x.guimard@free.frE<gt>
+=item Copyright (C) 2009-2012 by Xavier Guimard, E<lt>x.guimard@free.frE<gt>
 
 =item Copyright (C) 2012 by François-Xavier Deltombe, E<lt>fxdeltombe@gmail.com.E<gt>
 
-=item Copyright (C) 2009, 2010, 2011, 2012, 2013 by Clement Oudot, E<lt>clem.oudot@gmail.comE<gt>
+=item Copyright (C) 2009-2016 by Clement Oudot, E<lt>clem.oudot@gmail.comE<gt>
 
 =item Copyright (C) 2010 by Thomas Chemineau, E<lt>thomas.chemineau@gmail.comE<gt>
 
