@@ -6,6 +6,7 @@
 package Lemonldap::NG::Portal::Menu;
 
 use strict;
+use utf8;
 use warnings;
 use Lemonldap::NG::Portal::Simple;
 use Lemonldap::NG::Portal::_LibAccess;
@@ -126,7 +127,7 @@ sub displayModules {
 # Returns categories and applications list as HTML::Template loop
 # @return categories and applications list
 sub appslist {
-    my ($self) = splice @_;
+    my ($self) = @_;
     my $appslist = [];
 
     return $appslist unless defined $self->{applicationList};
@@ -151,7 +152,7 @@ sub appslist {
 # @param catlevel Category level
 # @return Category Hash
 sub _buildCategoryHash {
-    my ( $self, $catid, $cathash, $catlevel ) = splice @_;
+    my ( $self, $catid, $cathash, $catlevel ) = @_;
     my $catname = $cathash->{catname} || $catid;
     my $applications;
     my $categories;
@@ -200,7 +201,7 @@ sub _buildCategoryHash {
 # @param $apphash Hash of application elements
 # @return Application Hash
 sub _buildApplicationHash {
-    my ( $self, $appid, $apphash ) = splice @_;
+    my ( $self, $appid, $apphash ) = @_;
     my $applications;
 
     # Get application items
@@ -286,7 +287,7 @@ sub appslistDescription {
 # @param catlevel Category level
 # @return HTML string
 sub _displayConfCategory {
-    my ( $self, $catname, $cathash, $catlevel ) = splice @_;
+    my ( $self, $catname, $cathash, $catlevel ) = @_;
     my $html;
     my $key;
 
@@ -427,7 +428,7 @@ sub _displayConfDescription {
 # @param $apphash Menu elements
 # @return filtered hash
 sub _filter {
-    my ( $self, $apphash ) = splice @_;
+    my ( $self, $apphash ) = @_;
     my $filteredHash;
     my $key;
 
@@ -602,11 +603,11 @@ L<http://forge.objectweb.org/project/showfiles.php?group_id=274>
 
 =over
 
-=item Copyright (C) 2008, 2009, 2010 by Xavier Guimard, E<lt>x.guimard@free.frE<gt>
+=item Copyright (C) 2008-2010 by Xavier Guimard, E<lt>x.guimard@free.frE<gt>
 
 =item Copyright (C) 2012 by François-Xavier Deltombe, E<lt>fxdeltombe@gmail.com.E<gt>
 
-=item Copyright (C) 2008, 2009, 2010, 2011, 2012, 2013 by Clement Oudot, E<lt>clem.oudot@gmail.comE<gt>
+=item Copyright (C) 2008-2016 by Clement Oudot, E<lt>clem.oudot@gmail.comE<gt>
 
 =back
 
