@@ -9,12 +9,14 @@ use strict;
 use Lemonldap::NG::Portal::Simple qw(:all);
 use Lemonldap::NG::Common::Conf;            #link protected lmConf Configuration
 use Lemonldap::NG::Common::Conf::Constants; #inherits
+use Regexp::Assemble;
+use URI::Split qw(uri_split);
 
 *EXPORT_OK   = *Lemonldap::NG::Portal::Simple::EXPORT_OK;
 *EXPORT_TAGS = *Lemonldap::NG::Portal::Simple::EXPORT_TAGS;
 *EXPORT      = *Lemonldap::NG::Portal::Simple::EXPORT;
 
-our $VERSION = '1.2.0';
+our $VERSION = '1.4.2';
 use base qw(Lemonldap::NG::Portal::Simple);
 our $confCached;
 
@@ -43,47 +45,77 @@ sub getConf {
         %args = @_;
     }
 
-    my $num = $self->__lmConf->lastCfg;
+    if ( defined( $args{configStorage} ) ) {
+        $self->{configStorage} = $args{configStorage};
+    }
+
+    my $num;
+    my $lConf;
+
+    # If useLocalConf is set, just verify that current conf has the same number
+    # than local cache one
+    if ( $confCached and $confCached->{useLocalConf} ) {
+        $lConf = $self->__lmConf->getLocalConf(PORTALSECTION);
+        eval { $num = $lConf->{cfgNum} };
+    }
+    else {
+        $num = $self->__lmConf->lastCfg();
+    }
 
     # Reload configuration
     unless ( $confCached and $confCached->{cfgNum} == $num ) {
-        $self->lmLog( "Cached configuration too old, get configuration $num",
-            'debug' );
-        my $gConf = $self->__lmConf->getConf( { cfgNum => $num } );
-        my $lConf = $self->__lmConf->getLocalConf(PORTALSECTION);
+        $lConf ||= $self->__lmConf->getLocalConf(PORTALSECTION);
+        my $prm = { cfgNum => $num };
+        if ( $args{useLocalConf} or $lConf->{useLocalConf} ) {
+            $prm->{local} = 1;
+            $self->lmLog( 'useLocalConf set to true', 'debug' );
+        }
+        my $gConf = $self->__lmConf->getConf($prm);
         unless ( ref($gConf) and ref($lConf) ) {
             $self->abort( "Cannot get configuration",
                 $Lemonldap::NG::Common::Conf::msg );
         }
+        $self->lmLog(
+            "Cached configuration too old, get configuration $num "
+              . "($Lemonldap::NG::Common::Conf::msg)",
+            'debug'
+        );
         %$confCached = ( %$gConf, %$lConf );
+
+        my $re = Regexp::Assemble->new();
+        foreach my $vhost ( keys %{ $confCached->{locationRules} } ) {
+            my $quotedVhost = quotemeta($vhost);
+            $self->lmLog( "Vhost $vhost added in reVHosts", 'debug' );
+            $re->add($quotedVhost);
+
+            # Add aliases
+            if ( $confCached->{vhostOptions}->{$vhost}->{vhostAliases} ) {
+                foreach my $alias ( split /\s+/,
+                    $confCached->{vhostOptions}->{$vhost}->{vhostAliases} )
+                {
+                    $self->lmLog( "Alias $alias added in reVHosts", 'debug' );
+                    $re->add( quotemeta($alias) );
+                }
+            }
+        }
+
+        # Add portal vhost
+        my ( $portal_scheme, $portal_auth ) =
+          uri_split( $confCached->{portal} );
+        $re->add($portal_auth);
+        $self->lmLog( "Portal vhost $portal_auth added in reVHosts", 'debug' );
+
+        $confCached->{reVHosts} = $re->as_string;
     }
 
     %$self = ( %$self, %$confCached, %args, );
 
-    # localStorage should be declared in configuration object
-    # See Handler::SharedConf
-    foreach (qw(localStorage localStorageOptions)) {
-        $self->{$_} ||= $self->__lmConf->{$_};
-    }
-
     $self->lmLog( "Now using configuration: " . $confCached->{cfgNum},
         'debug' );
 
     1;
 }
 
-## @method list getProtectedSites()
-# With SharedConf, $locationRules contains a hash table with virtual hosts as
-# keys. So we can use it to know all protected virtual hosts.
-# @return list list of protected virtual hosts.
-sub getProtectedSites {
-    my $self = shift;
-    my @tab  = ();
-    return ( keys %{ $self->{locationRules} } )
-      if ( ref $self->{locationRules} );
-    return ();
-}
-
 sub __lmConf {
     my $self = shift;
     return $self->{lmConf} if ( $self->{lmConf} );
@@ -123,7 +155,7 @@ compatible portals using a central configuration database.
   if($portal->process()) {
     # Write here the menu with CGI methods. This page is displayed ONLY IF
     # the user was not redirected here.
-    print $portal->header('text/html; charset=utf8'); # DON'T FORGET THIS (see L<CGI(3)>)
+    print $portal->header('text/html; charset=utf-8'); # DON'T FORGET THIS (see L<CGI(3)>)
     print "...";
 
     # or redirect the user to the menu
@@ -133,14 +165,14 @@ compatible portals using a central configuration database.
     # Write here the html form used to authenticate with CGI methods.
     # $portal->error returns the error message if athentification failed
     # Warning: by defaut, input names are "user" and "password"
-    print $portal->header('text/html; charset=utf8'); # DON'T FORGET THIS (see L<CGI(3)>)
+    print $portal->header('text/html; charset=utf-8'); # DON'T FORGET THIS (see L<CGI(3)>)
     print "...";
     print '<form method="POST">';
     # In your form, the following value is required for redirection
     print '<input type="hidden" name="url" value="'.$portal->param('url').'">';
     # Next, login and password
     print 'Login : <input name="user"><br>';
-    print 'Password : <input name="password" type="password" autocomplete="off">';
+    print 'Password : <input name="password" type="password">';
     print '<input type="submit" value="go" />';
     print '</form>';
   }
@@ -219,7 +251,7 @@ L<http://lemonldap-ng.org/>
 
 =item Clement Oudot, E<lt>clem.oudot@gmail.comE<gt>
 
-=item Franois-Xavier Deltombe, E<lt>fxdeltombe@gmail.com.E<gt>
+=item François-Xavier Deltombe, E<lt>fxdeltombe@gmail.com.E<gt>
 
 =item Xavier Guimard, E<lt>x.guimard@free.frE<gt>
 
@@ -239,11 +271,11 @@ L<http://forge.objectweb.org/project/showfiles.php?group_id=274>
 
 =over
 
-=item Copyright (C) 2006, 2007, 2008, 2009, 2010 by Xavier Guimard, E<lt>x.guimard@free.frE<gt>
+=item Copyright (C) 2005-2015 by Xavier Guimard, E<lt>x.guimard@free.frE<gt>
 
-=item Copyright (C) 2012 by Franois-Xavier Deltombe, E<lt>fxdeltombe@gmail.com.E<gt>
+=item Copyright (C) 2012 by François-Xavier Deltombe, E<lt>fxdeltombe@gmail.com.E<gt>
 
-=item Copyright (C) 2006, 2009, 2010, 2011, 2012 by Clement Oudot, E<lt>clem.oudot@gmail.comE<gt>
+=item Copyright (C) 2006-2015 by Clement Oudot, E<lt>clem.oudot@gmail.comE<gt>
 
 =back
 
