@@ -9,7 +9,7 @@ use strict;
 use Lemonldap::NG::Portal::Simple;
 use Lemonldap::NG::Portal::_LDAP 'ldap';    #link protected ldap
 
-our $VERSION = '1.4.9';
+our $VERSION = '1.4.6';
 
 ## @method int userDBInit()
 # Transform ldapGroupAttributeNameSearch in ARRAY ref
@@ -76,6 +76,7 @@ sub search {
         base   => $self->{ldapBase},
         scope  => 'sub',
         filter => $self->{LDAPFilter},
+        deref  => $self->{ldapSearchDeref} || 'find',
         attrs  => \@attrs,
     );
     $self->lmLog(
@@ -184,6 +185,33 @@ sub setGroups {
     PE_OK;
 }
 
+## @method boolean setUserDBValue(string key, string value)
+# Store a value in UserDB
+# @param key Key in user information
+# @param value Value to store
+# @return result
+sub setUserDBValue {
+    my ( $self, $key, $value ) = @_;
+
+    # Mandatory attributes
+    return 0 unless defined $key;
+
+    # Write in LDAP
+    $self->lmLog( "Replace $key attribute in LDAP with value $value", 'debug' );
+    my $modification =
+      $self->{ldap}->modify( $self->{dn}, replace => { $key => $value } );
+
+    # Check result
+    if ( $modification->code ) {
+        $self->lmLog(
+            "LDAP error " . $modification->code . ": " . $modification->error,
+            'error' );
+        return 0;
+    }
+
+    return 1;
+}
+
 ## @apmethod int userDBFinish()
 # Unbind.
 # @return Lemonldap::NG::Portal constant
