@@ -15,7 +15,7 @@ use Unicode::String qw(utf8);
 use strict;
 
 our @EXPORT   = qw(ldap);
-our $VERSION  = '1.4.11';
+our $VERSION  = '1.4.6';
 our $ppLoaded = 0;
 
 BEGIN {
@@ -90,10 +90,10 @@ sub new {
 sub bind {
     my $self = shift;
     my $mesg;
-    my ( $dn, %args ) = splice @_;
+    my ( $dn, %args ) = @_;
     unless ($dn) {
         $dn = $self->{portal}->{managerDn};
-        $args{password} = $self->{portal}->{managerPassword};
+        $args{password} = decode( 'utf-8', $self->{portal}->{managerPassword} );
     }
     if ( $dn && $args{password} ) {
         if ( $self->{portal}->{ldapPwdEnc} ne 'utf-8' ) {
@@ -114,22 +114,6 @@ sub bind {
     return $mesg;
 }
 
-## @method Net::LDAP::Message unbind()
-# Reimplementation of Net::LDAP::unbind() to force call to disconnect()
-# @return Net::LDAP::Message
-sub unbind {
-    my $self     = shift;
-    my $ldap_uri = $self->{portal}->{ldapServer};
-    eval { $ldap_uri = $self->uri; };
-
-    $self->{portal}->lmLog( "Unbind and disconnect from $ldap_uri", 'debug' );
-
-    my $mesg = $self->SUPER::unbind();
-    $self->SUPER::disconnect();
-
-    return $mesg;
-}
-
 ## @method private boolean loadPP ()
 # Load Net::LDAP::Control::PasswordPolicy
 # @return true if succeed.
@@ -245,8 +229,7 @@ sub userBind {
 # @param $ad Active Directory mode
 # @return Lemonldap::NG::Portal constant
 sub userModifyPassword {
-    my ( $self, $dn, $newpassword, $confirmpassword, $oldpassword, $ad ) =
-      splice @_;
+    my ( $self, $dn, $newpassword, $confirmpassword, $oldpassword, $ad ) = @_;
     my $ppolicyControl     = $self->{portal}->{ldapPpolicyControl};
     my $setPassword        = $self->{portal}->{ldapSetPassword};
     my $asUser             = $self->{portal}->{ldapChangePasswordAsUser};
@@ -536,7 +519,7 @@ sub ldap {
 # @param attributes to get from found groups (array ref)
 # @return hashRef groups
 sub searchGroups {
-    my ( $self, $base, $key, $value, $attributes ) = splice @_;
+    my ( $self, $base, $key, $value, $attributes ) = @_;
 
     my $portal = $self->{portal};
     my $groups = {};
@@ -620,7 +603,7 @@ sub searchGroups {
 # @param attribute Attribute name
 # @return string value
 sub getLdapValue {
-    my ( $self, $entry, $attribute ) = splice @_;
+    my ( $self, $entry, $attribute ) = @_;
 
     return $entry->dn() if ( $attribute eq "dn" );
 
